timeintervaltools.TimeInterval
==============================

.. inheritance-diagram:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval
   :private-bases:

.. autoclass:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.bounds

   .. note:: Inherited from :py:class:`timeintervaltools.TimeIntervalMixin <abjad.tools.timeintervaltools.TimeIntervalMixin.TimeIntervalMixin.TimeIntervalMixin>`

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.center

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.duration

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.signature

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.start

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.stop

Methods
-------

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.clear

   .. note:: Inherited from `_abcoll.MutableMapping`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.get

   .. note:: Inherited from `_abcoll.Mapping`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.get_overlap_with_interval

   .. note:: Inherited from :py:class:`timeintervaltools.TimeIntervalMixin <abjad.tools.timeintervaltools.TimeIntervalMixin.TimeIntervalMixin.TimeIntervalMixin>`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_contained_by_interval

   .. note:: Inherited from :py:class:`timeintervaltools.TimeIntervalMixin <abjad.tools.timeintervaltools.TimeIntervalMixin.TimeIntervalMixin.TimeIntervalMixin>`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_container_of_interval

   .. note:: Inherited from :py:class:`timeintervaltools.TimeIntervalMixin <abjad.tools.timeintervaltools.TimeIntervalMixin.TimeIntervalMixin.TimeIntervalMixin>`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_overlapped_by_interval

   .. note:: Inherited from :py:class:`timeintervaltools.TimeIntervalMixin <abjad.tools.timeintervaltools.TimeIntervalMixin.TimeIntervalMixin.TimeIntervalMixin>`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_tangent_to_interval

   .. note:: Inherited from :py:class:`timeintervaltools.TimeIntervalMixin <abjad.tools.timeintervaltools.TimeIntervalMixin.TimeIntervalMixin.TimeIntervalMixin>`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.items

   .. note:: Inherited from `_abcoll.Mapping`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.iteritems

   .. note:: Inherited from `_abcoll.Mapping`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.iterkeys

   .. note:: Inherited from `_abcoll.Mapping`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.itervalues

   .. note:: Inherited from `_abcoll.Mapping`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.keys

   .. note:: Inherited from `_abcoll.Mapping`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.pop

   .. note:: Inherited from `_abcoll.MutableMapping`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.popitem

   .. note:: Inherited from `_abcoll.MutableMapping`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.quantize_to_rational

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.scale_by_rational

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.scale_to_rational

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.setdefault

   .. note:: Inherited from `_abcoll.MutableMapping`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.shift_by_rational

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.shift_to_rational

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.split_at_rationals

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.update

   .. note:: Inherited from `_abcoll.MutableMapping`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.values

   .. note:: Inherited from `_abcoll.Mapping`

Special Methods
---------------

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__contains__

   .. note:: Inherited from `_abcoll.Mapping`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__delitem__

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__eq__

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__getitem__

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__hash__

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__iter__

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__len__

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__ne__

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__nonzero__

   .. note:: Inherited from :py:class:`timeintervaltools.TimeIntervalMixin <abjad.tools.timeintervaltools.TimeIntervalMixin.TimeIntervalMixin.TimeIntervalMixin>`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__repr__

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__setitem__

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__str__

   .. note:: Inherited from `__builtin__.object`
